# ps5000a Reference
## Initializing ps5000a
```
import pypicosdk as psdk

scope = psdk.ps5000a()

scope.open_unit()
# Do something
scope.close_unit()
```

## Reference
::: pypicosdk.pypicosdk.ps5000a
    options:
        filters:
        - "!.*_to_.*"
        - "!^_[^_]"